.. only:: html

   .. nbinfo::

      Download a PDF version of the documentation: :pdf:`pyblp.pdf <>`


PyBLP
=====

.. only:: html

   The documentation can be navigated with the sidebar, the links below, or the :ref:`index <genindex>`.

.. raw:: latex

   \part{User Documentation}

.. toctree::
   :caption: User Documentation
   :maxdepth: 2

   introduction
   notation
   background
   tutorial
   api
   references
   legal

.. raw:: latex

   \part{Developer Documentation}

.. toctree::
   :caption: Developer Documentation
   :maxdepth: 2

   contributing
   testing
   versions

.. raw:: latex

   \part{Indices}
